@@ -116,7 +116,7 @@ impl Assert {
         self.do_action(
             expected,
             actual,
-            Some(&pattern_path.display()),
+            Some(&crate::path::display_relpath(pattern_path)),
             Some(&"In-memory"),
             pattern_path,
         );
@@ -164,7 +164,7 @@ impl Assert {
         self.do_action(
             expected,
             actual,
-            Some(&pattern_path.display()),
+            Some(&crate::path::display_relpath(pattern_path)),
             Some(&"In-memory"),
             pattern_path,
         );
@@ -290,12 +290,12 @@ impl Assert {
     #[track_caller]
     pub fn subset_eq(
         &self,
-        pattern_root: impl Into<std::path::PathBuf>,
+        expected_root: impl Into<std::path::PathBuf>,
         actual_root: impl Into<std::path::PathBuf>,
     ) {
-        let pattern_root = pattern_root.into();
+        let expected_root = expected_root.into();
         let actual_root = actual_root.into();
-        self.subset_eq_inner(pattern_root, actual_root)
+        self.subset_eq_inner(expected_root, actual_root)
     }
 
     #[track_caller]
