@@ -194,3 +194,50 @@ pub fn assert_matches_path(
         .action_env("SNAPSHOTS")
         .matches_path(pattern_path, actual);
 }
+
+/// Check if a path matches the content of another path, recursively
+///
+/// When the content is text, newlines are normalized.
+///
+/// ```rust,no_run
+/// let output_root = "...";
+/// let expected_root = "tests/snapshots/output.txt";
+/// snapbox::assert_subset_eq(expected_root, output_root);
+/// ```
+#[cfg(feature = "path")]
+#[track_caller]
+pub fn assert_subset_eq(
+    expected_root: impl Into<std::path::PathBuf>,
+    actual_root: impl Into<std::path::PathBuf>,
+) {
+    Assert::new()
+        .action_env("SNAPSHOTS")
+        .subset_eq(expected_root, actual_root);
+}
+
+/// Check if a path matches the pattern of another path, recursively
+///
+/// Pattern syntax:
+/// - `...` is a line-wildcard when on a line by itself
+/// - `[..]` is a character-wildcard when inside a line
+/// - `[EXE]` matches `.exe` on Windows
+///
+/// Normalization:
+/// - Newlines
+/// - `\` to `/`
+///
+/// ```rust,no_run
+/// let output_root = "...";
+/// let expected_root = "tests/snapshots/output.txt";
+/// snapbox::assert_subset_matches(expected_root, output_root);
+/// ```
+#[cfg(feature = "path")]
+#[track_caller]
+pub fn assert_subset_matches(
+    pattern_root: impl Into<std::path::PathBuf>,
+    actual_root: impl Into<std::path::PathBuf>,
+) {
+    Assert::new()
+        .action_env("SNAPSHOTS")
+        .subset_matches(pattern_root, actual_root);
+}
